<template>
	<div class="w100 h100">
		<div class="aisde-title">
			<div
				class="flex items-center set-li"
				v-for="(item, index) in state.asideTitleList"
				:key="index"
				@click="handleClick(item)"
				:class="{ 'set-li-active': item.routerName === currentRoute.name }"
			>
				<img :src="item.icon" alt="" class="pl-2.5 pr-2.5 w-4 h-4" style="box-sizing: content-box" />
				<span class="font-medium text-sm text-white tracking-wide">{{ item.title }}</span>
			</div>
		</div>
		<div class="user_text" v-if="isLoginStatus">
			<div class="user_head">
				<span
					><span
						><span class="user-head">{{ firstUserCharacter }}</span
						><span class="identifying"><!----></span></span
					><span class="user_name"> {{ userName }} </span></span
				><span ref="toggleExitLoginBtnRef"
					><span
						class="ywicon text-white"
						:class="{ 'icon-fold': !state.isShowExitLogin, 'icon-unfold': state.isShowExitLogin }"
						@click="toggleShowExitLogin"
					></span
				></span>
			</div>
			<div class="pop_up actived" v-show="state.isShowExitLogin">
				<div class="exit" @click="logoutClick"><i class="ywicon icon-tuichu"></i> 退出登录</div>
			</div>
		</div>
		<div v-else class="user_login">
			<div class="set-login" @click="openLoginDlg">
				<span class="text-stone-100 font-medium text-sm text-center">登录 / 注册</span>
			</div>
		</div>
	</div>
	<div class="pc-login items-center justify-center" style="display: flex" v-show="state.isShowLogin">
		<div class="login_box">
			<div class="sign_in">
				<i class="ywicon icon-guanbi closes" @click="handleClose"></i>
				<h1><span>登录 WI 水务</span></h1>
				<el-form ref="loginFormRef" :model="state.loginForm" :rules="loginRules" class="demo-ruleForm mt-[24px]" size="large">
					<el-form-item label="账号" prop="account">
						<el-input v-model="state.loginForm.account" clearable />
					</el-form-item>
					<el-form-item label="密码" prop="pwd">
						<el-input v-model="state.loginForm.pwd" type="password" autocomplete="off" clearable />
					</el-form-item>
				</el-form>
				<div class="mt-[24px]">
					<el-button type="primary" @click="onSubmit" class="set-login_btn">登录</el-button>
				</div>
			</div>
		</div>
	</div>
</template>

<script setup lang="ts">
import type { FormInstance } from 'element-plus';
import { computed, onMounted, reactive, ref, watchEffect } from 'vue';
import { PostLogin } from '/@/api/ai/user';
import router from '/@/router';
import emitter from '/@/utils/mitt';
import { accessSessionKey, userNameKey } from '/@/utils/request';
import { gotoRoute } from '/@/utils/route';
import { Local, LoginInfo } from '/@/utils/storage';

const loginFormRef = ref<FormInstance>(null);
const isLoginStatus = ref(!!Local.get(accessSessionKey));

const userName = ref('');
const firstUserCharacter = computed(() => userName.value?.[0]?.toUpperCase());
watchEffect(() => {
	if (!isLoginStatus.value) return;
	userName.value = Local.get(userNameKey);
});
let state = reactive({
	asideTitleList: [
		{
			id: 1,
			icon: '/static/images/wave/AsideIcon.png',
			title: '应用场景',
			routerName: 'AllScenario',
		},
		{
			id: 2,
			icon: '/static/images/wave/AsideIcon.png',
			title: '帮助中心',
			// routerName:'Scenario',
		},
		{
			id: 3,
			icon: '/static/images/wave/AsideIcon.png',
			title: '个人设置',
		},
		{
			id: 4,
			icon: '/static/images/wave/AsideIcon.png',
			title: '关于WI 水务智能',
			routerName: 'AboutUs',
		},
	],
	isShowLogin: false,
	isShowExitLogin: false,
	loginForm: {
		account: '',
		pwd: '',
	},
});
const loginRules = reactive({
	account: [{ required: true, message: '请输入账号', trigger: 'blur' }],
	pwd: [{ required: true, message: '请输入密码', trigger: 'blur' }],
});
const handleClick = (item) => {
	gotoRoute({ name: item.routerName });
};
//登录
const openLoginDlg = async () => {
	state.isShowLogin = true;
};
const handleClose = () => {
	state.isShowLogin = false;
};
//登录
const onSubmit = async () => {
	const isValid = await loginFormRef.value.validate().catch(() => {});
	if (!isValid) return;
	const res = await PostLogin({
		user: state.loginForm.account,
		pass: state.loginForm.pwd,
	});

	LoginInfo.set(res.hswatersession,state.loginForm.account);
	state.isShowLogin = false;
	isLoginStatus.value = true;
	window.location.reload();
};

const currentRoute = router.currentRoute;

//是否显示退出登录弹窗cpolar.top/login
const toggleShowExitLogin = () => {
	state.isShowExitLogin = !state.isShowExitLogin;
};
//退出登录
const logoutClick = () => {
	state.isShowExitLogin = false;
	isLoginStatus.value = false;
	LoginInfo.remove();
};
const toggleExitLoginBtnRef = ref<HTMLDivElement>(null);

const listenClickOtherExit = (e) => {
	if (toggleExitLoginBtnRef.value !== e.target && !toggleExitLoginBtnRef.value?.contains(e.target)) {
		state.isShowExitLogin = false;
	}
};

onMounted(() => {
	emitter.on('openLoginDlg', () => {
		if (state.isShowLogin || isLoginStatus.value) return;
		openLoginDlg();
	});

	emitter.on('logout', () => {
		logoutClick();
	});

	document.addEventListener('click', listenClickOtherExit);
});
</script>
<style scoped lang="scss">
.aisde-title {
	padding-top: 18px;
	margin-left: 16px;
	margin-right: 22px;
	border-top: 1px solid #383838;
	margin-bottom: 22px;
}
.set-li {
	height: 30px;
	margin-bottom: 4px;
	display: flex;
	-webkit-box-align: center;
	-ms-flex-align: center;
	align-items: center;
	cursor: pointer;
}
.set-li-active {
	width: 214px;
	height: 30px;
	background-color: #3b3d40;

	border-radius: 6px;
	span {
		background: linear-gradient(90deg, #84fdd4 0, #2a82e4);
		background-clip: text;
		-webkit-background-clip: text;
		-webkit-text-fill-color: transparent;
	}
}
.user_text {
	box-sizing: border-box;
	width: 100%;
	padding: 0 20px 10px;
	position: relative;
	.user_head {
		display: flex;
		align-items: center;
		justify-content: space-between;
		margin-bottom: 12px;
		span:first-child {
			display: flex;
			align-items: center;
			span:first-child {
				position: relative;
				.user-head {
					margin-right: 6px;
					width: 30px;
					height: 30px;
					border-radius: 50%;
					cursor: pointer;
					display: flex;
					align-items: center;
					justify-content: center;
					background-color: #1d86ff;
					font-size: 12px;
					color: #fff;
				}
				.identifying {
					position: absolute;
					left: 17px;
					top: -12px;
					color: #fff;
					display: flex;
				}
			}
			.user_name {
				position: relative;
				width: 145px;
				overflow: hidden;
				-o-text-overflow: ellipsis;
				text-overflow: ellipsis;
				font-size: 14px;
				font-weight: 700;
				letter-spacing: 0;
				line-height: 23.17px;
				color: #fff;
				white-space: nowrap;
			}
		}
		span:last-child {
			margin-right: 21px;
			cursor: pointer;
			span {
				display: flex;
				justify-content: center;
				align-items: center;
				width: 30px;
				height: 30px;
				border: 1px solid #414141;
				border-radius: 50%;
			}
		}
	}
	.pop_up {
		position: absolute;
		top: -60px;
		left: 5px;
		width: 240px;
		min-height: 47px;
		opacity: 1;
		border-radius: 15px;
		background: #1f1f1f;
		border: 1px solid #737373;
		.exit {
			font-size: 14px;
			font-weight: 400;
			line-height: 20.27px;
			color: #b9b9b9;
			margin-top: 17px;
			margin-left: 24px;
			cursor: pointer;
			padding-bottom: 10px;
		}
	}
	.actived {
		top: -60px !important;
	}
}
.user_login {
	box-sizing: border-box;
	width: 100%;
	padding: 0 20px 10px;
	position: relative;
}
.set-login {
	margin-top: 14px;
	width: 100%;
	height: 36px;
	background: #1c86ff;
	-webkit-box-shadow: 0 2px 6px 0 rgba(8, 101, 207, 0.2), inset 0 0 7px 0 hsla(0, 0%, 100%, 0.5);
	box-shadow: 0 2px 6px 0 rgba(8, 101, 207, 0.2), inset 0 0 7px 0 hsla(0, 0%, 100%, 0.5);
	display: flex;
	-webkit-box-align: center;
	-ms-flex-align: center;
	align-items: center;
	-webkit-box-pack: center;
	-ms-flex-pack: center;
	justify-content: center;
	font-size: 14px;
	font-weight: 500;
	color: #eee;
	border-radius: 8px;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
	cursor: pointer;
	-webkit-transition: all 0.3s;
	-o-transition: all 0.3s;
	transition: all 0.3s;
}
.offices {
	padding: 0 20px;
	cursor: pointer;
	text-decoration: none;
	position: relative;
}
.officeText {
	width: 100%;
	height: 36px;
	background: #1c2d57;
	border-radius: 8px;
	display: flex;
	-webkit-box-align: center;
	-ms-flex-align: center;
	align-items: center;
	-webkit-box-pack: center;
	-ms-flex-pack: center;
	justify-content: center;
}
.pc-login {
	position: fixed;
	top: 0;
	left: 0;
	width: 100vw;
	height: 100vh;
	z-index: 2000;
	background-color: rgba(0, 0, 0, 0.6);
	.login_box {
		position: relative;
		width: 450px;
		margin: 15vh auto;
		.sign_in {
			padding: 39px;
			position: relative;
			width: 100%;
			height: 100%;
			border-radius: 12px;
			-webkit-box-sizing: border-box;
			box-sizing: border-box;
			display: flex;
			-webkit-box-orient: vertical;
			-webkit-box-direction: normal;
			-ms-flex-direction: column;
			flex-direction: column;
			-webkit-box-align: center;
			-ms-flex-align: center;
			align-items: center;
			background-color: #fff;
			-webkit-box-shadow: 0 0 16px 0 rgba(20, 29, 53, 0.21);
			box-shadow: 0 0 16px 0 rgba(20, 29, 53, 0.21);
			.closes {
				position: absolute;
				top: -28px;
				right: -38px;
				font-size: 30px;
				cursor: pointer;
				color: #eee;
				-o-transition: color 0.1s;
				transition: color 0.1s;
			}
			h1 {
				box-sizing: content-box;
				width: 100%;
				font-size: 30px;
				font-weight: 500;
				color: #1c153a;
				text-align: left !important;
			}
			.demo-ruleForm {
				:deep(.el-input__wrapper) {
					position: relative;
					margin-bottom: 12px;
					display: flex;
					-webkit-box-align: center;
					-ms-flex-align: center;
					align-items: center;
					width: 346px;
					// height: 44px;
					background-color: #fff;
					border-radius: 5px;
				}
			}
			.set-pwd {
				text-align: right;
				font-size: 14px;
				font-weight: 300;
				color: #999;
				width: 100%;
				padding: 0px 32px;
			}
			.set-login_btn {
				width: 366px;
				height: 44px;
				font-size: 16px;
				font-weight: 500;
				color: #fff;
				background: #0a58ed;
				border-radius: 12px;
				-webkit-box-shadow: 4px 6px 15px rgba(10, 88, 237, 0.2);
				box-shadow: 4px 6px 15px rgba(10, 88, 237, 0.2);
			}
		}
	}
}
</style>
